@@ -2,10 +2,12 @@ from .ccxt_portfolio_manager import CCXTPortfolioManager, \
     CCXTSQLitePortfolioManager
 from .portfolio_manager import PortfolioManager
 from .sqllite_portfolio_manager import SQLLitePortfolioManager
+from .stateless import StatelessPortfolioManager
 
 __all__ = [
     "PortfolioManager",
     "SQLLitePortfolioManager",
     "CCXTPortfolioManager",
     "CCXTSQLitePortfolioManager",
+    "StatelessPortfolioManager"
 ]
